Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SelectContext ¶
func SelectContext(contexts []datumconfig.DiscoveredContext, cfg *datumconfig.ConfigV1Beta1) (string, error)
SelectContext presents an interactive picker for choosing a context. If only one context is available, it is auto-selected. Returns the context name.
func SelectSession ¶
func SelectSession(sessions []*datumconfig.Session) (string, error)
SelectSession presents an interactive picker for disambiguating between sessions that share the same email. Returns the session name.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.